==> RSTouchscreenNG-1.3.0.zip: RSTouchscreenNG/projects/binding/src/lib/reducer/ConnectionReducer.ts <==
/* (C) 2016-2021 Hot-World GmbH & Co. KG <rlittwin@repetier.com>
 All Rights Reserved

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
 DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

 It is allowed to use this code to create or use in products connecting to
 Repetier-Server or to use it for own plugins/modules with Repetier-Server.
 This includes free and commercial products.
 Usage for other products is strictly forbidden.
 */

import {
  ConnectionConnectedAction,
  ConnectionDisconnectedAction, ConnectionSetApiKeyAction, ConnectionSetConApiKeyAction,
  ConnectionSetSessionAction
} from "../actions/ConnectionAction";
import type {ConnectionState
} from "../state/RepetierState";
import {Action, createReducer, on} from "@ngrx/store";
import {INITIAL_CONNECTION_STATE} from "../state/RepetierState";

const reducer = createReducer(INITIAL_CONNECTION_STATE,
    on(ConnectionConnectedAction, state =>
      Object.assign({}, state, {connected: true})),
    on(ConnectionDisconnectedAction, state =>
       Object.assign({}, state, {connected: false})),
    on(ConnectionSetSessionAction, (state, {session}) =>
      Object.assign({}, state, {session})),
    on(ConnectionSetApiKeyAction, (state, payload) =>
      Object.assign({}, state, {apikey: payload})),
    on(ConnectionSetConApiKeyAction, (state, payload) =>
      Object.assign({}, state, payload))
);

export function ConnectionReducer(state: ConnectionState | undefined, action: Action):ConnectionState {
  try {
  return reducer(state, action);
  } catch (e) {
    console.error("ConnectionReducer error", e);
    return state;
  }
}

==> RSTouchscreenNG-1.4.16.zip: RSTouchscreenNG/projects/binding/src/lib/reducer/ConnectionReducer.ts <==
/* (C) 2016-2023 Hot-World GmbH & Co. KG <rlittwin@repetier.com>
 All Rights Reserved

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
 DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

 It is allowed to use this code to create or use in products connecting to
 Repetier-Server or to use it for own plugins/modules with Repetier-Server.
 This includes free and commercial products.
 Usage for other products is strictly forbidden.
 */

import {
  ConnectionConnectedAction,
  ConnectionDisconnectedAction, ConnectionSetApiKeyAction, ConnectionSetConApiKeyAction,
  ConnectionSetSessionAction
} from "../actions/ConnectionAction";
import type {
  ConnectionState
} from "../state/RepetierState";
import {Action, createReducer, on} from "@ngrx/store";
import {INITIAL_CONNECTION_STATE} from "../state/RepetierState";

const reducer = createReducer(INITIAL_CONNECTION_STATE,
  on(ConnectionConnectedAction, state =>
    Object.assign({}, state, {connected: true})),
  on(ConnectionDisconnectedAction, state =>
    Object.assign({}, state, {connected: false})),
  on(ConnectionSetSessionAction, (state, {session}) =>
    Object.assign({}, state, {session})),
  on(ConnectionSetApiKeyAction, (state, payload) =>
    Object.assign({}, state, {apikey: payload})),
  on(ConnectionSetConApiKeyAction, (state, payload) =>
    Object.assign({}, state, JSON.parse(JSON.stringify(payload))))
);

export function ConnectionReducer(state: ConnectionState | undefined, action: Action): ConnectionState {
  try {
    return reducer(state, action);
  } catch (e) {
    console.error("ConnectionReducer error", e);
    return state;
  }
}
